@@ -346,12 +346,10 @@ class MessageTypes(object):
                 if msg.status == motorcortex.OK:
                     value_type = self.__types_by_hash[param.info.data_type]
                     params.append(ParameterMsg(param.header, param.info,
-                                               value_type.decode(param.value, param.info.number_of_elements,
-                                                                 motorcortex.OK)))
+                                               value_type.decode(param.value, param.info.number_of_elements),
+                                               motorcortex.OK))
                 else:
-                    params.append(ParameterMsg(param.header, param.info,
-                                               value_type.decode(param.value, param.info.number_of_elements,
-                                                                 msg.status)))
+                    params.append(ParameterMsg(msg.header, msg.info, None, msg.status))
             return ParameterListMsg(msg.header, params)
 
         return msg
