@@ -402,6 +402,26 @@ class ConnectionTimeout(unittest.TestCase):
         req.close()
 
 
+class GetParameter(unittest.TestCase):
+    def test(self):
+        # Creating empty object for parameter tree
+        parameter_tree = motorcortex.ParameterTree()
+
+        # Loading protobuf types and hashes
+        motorcortex_types = motorcortex.MessageTypes()
+
+        # Open request connection
+        req, sub = motorcortex.connect("wss://192.168.179.85:5568:5567", motorcortex_types, parameter_tree,
+                                       certificate="mcx.cert.pem", timeout_ms=5000,
+                                       login="test", password="test")
+
+        rep = req.getParameterList(["root/Logic/mode",
+                                    "root/Logic/modeCommand"]).get()
+        print(f"{rep}")
+
+        rep.close()
+
+
 class SubParameter(unittest.TestCase):
     counter = 0
 
